@@ -218,9 +218,8 @@ class DockerSwarmOperator(DockerOperator):
         if self.service and self._service_status() == "complete":
             self.tasks = self.cli.tasks(filters={"service": self.service["ID"]})
             for task in self.tasks:
-                container_id = task["Status"]["ContainerStatus"]["ContainerID"]
-                container = self.cli.inspect_container(container_id)
-                self.containers.append(container)
+                docker_service = self.cli.inspect_service(task["ServiceID"])
+                self.containers.append(docker_service)
 
         if self.retrieve_output:
             return self._attempt_to_retrieve_results()
@@ -230,7 +229,7 @@ class DockerSwarmOperator(DockerOperator):
             if self.auto_remove == "force":
                 self.cli.remove_service(self.service["ID"])
             raise AirflowException(f"Service did not complete: {self.service!r}")
-        elif self.auto_remove in ["success", "force"]:
+        if self.auto_remove in ["success", "force"]:
             if not self.service:
                 raise RuntimeError("The 'service' should be initialized before!")
             self.cli.remove_service(self.service["ID"])
@@ -296,8 +295,7 @@ class DockerSwarmOperator(DockerOperator):
                 file_contents.append(file_content)
             if len(file_contents) == 1:
                 return file_contents[0]
-            else:
-                return file_contents
+            return file_contents
         except APIError:
             return None
 
